@@ -494,7 +494,11 @@ class Graph(object):
             handles, labels = self.axes.get_legend_handles_labels()
         if handles and labels:
             # Determine 'small' or 'large'
-            if self.width < 500 or force_legend_below:
+            # if self.width < 500 or force_legend_below:
+            if force_legend_below:
+                # TODO: Maybe remove this feature? Needs tweaking. The
+                # legend is still on top of the graph, while the graph
+                # reserves room for the legend below.
                 legend_loc = 4  # lower right
                 # approximation of legend height
                 self.legend_on_bottom_height = min(
@@ -504,7 +508,23 @@ class Graph(object):
             else:
                 legend_loc = 1  # Upper right'
 
-            return self.figure.legend(
+            # For width 464 (empty space 150px assumed), we have:
+            # <= 40 = medium
+            # > 40 = small
+            # > 50 = x-small
+            # > 65 = xx-small
+            # Fixes #3095
+            font_len = max([len(label) for label in labels])
+            font_size = 'medium'  #'medium'
+            if font_len > 40 * ((self.width - 150) / 314.0):
+                font_size = 'small'
+            if font_len > 50 * ((self.width - 150) / 314.0):
+                font_size = 'x-small'
+            if font_len > 65 * ((self.width - 150) / 314.0):
+                font_size = 'xx-small'
+            prop = {'size': font_size}
+
+            return self.axes.legend(
                 handles,
                 labels,
                 bbox_to_anchor=(1 - self.legend_width,
@@ -513,12 +533,14 @@ class Graph(object):
                                 # 1 = Upper right of above bbox. Use 0 for
                                 # 'best'
                                 1),
+                prop=prop,
                 loc=legend_loc,
                 ncol=ncol,
                 fancybox=True,
                 shadow=True,)
          #legend.set_size('medium')
          # TODO: get rid of the border around the legend.
+         # to get rid of the border: graph.axes.legend_.draw_frame(False)
 
     def init_second_axes(self):
         """ init second axes """
