@@ -2,8 +2,8 @@
 /*jslint browser: true */
 /*global $, OpenLayers, window, updateLayers, addProgressAnimationIntoWorkspace,
 stretchOneSidebarBox, reloadGraphs, fillSidebar, show_popup,
-alert,
-hover_popup, layers, map, refreshLayers, isCollagePopupVisible */
+alert, setUpTooltips,
+hover_popup, layers, wms_layers, map, refreshLayers, isCollagePopupVisible */
 
 var animationTimer, transparencyTimer;
 
@@ -81,12 +81,20 @@ function setUpTransparencySlider() {
         step: 1,
         value: transparency_slider_value,
         slide: function (event, ui) {
+            var index;
             $('#map').data("transparency_slider_value", ui.value);
             $(layers).each(function (i, layer) {
                 if (layer !== undefined) {
                     layer.setOpacity(ui.value / 100);
                 }
             });
+            // WMS layers
+            for (index in wms_layers) {
+                // Lint wants an if statement.. why?
+                if (true) {
+                    wms_layers[index].setOpacity(ui.value / 100);
+                }
+            }
         }
     });
 }
@@ -174,6 +182,9 @@ function setUpAddWorkspaceItem() {
         if ($(".workspace .workspace-item").length > 7) {
             alert("Pas op, meer dan 8 workspace items zorgt voor traagheid.");
         }
+        // Temporary disable sorting. It gets enabled again in
+        // updateWorkspace.
+        $(".workspace ul.workspace-items").sortable("disable");
         // Request to make workspace item and update workspace.
         $.post(
             url,
@@ -200,24 +211,15 @@ function setUpWorkspaceAcceptable() {
     // See http://tinyurl.com/29lg4y3 .
     $(".workspace-acceptable").live("mouseover", function () {
         var html;
-        if (!$(this).data("draggable-initialized")) {
-            $(this).data("draggable-initialized", true);
-            $(this).draggable({
-                scroll: 'false',
-                cursor: 'move',
-                helper: 'clone',
-                appendTo: 'body',
-
-                revert: 'true',
-                placeholder: 'ui-sortable-placeholder'
-            });
-        }
         if (!$(this).data("add-workspace-item-initialized")) {
             // Add the "add to workspace" button
             $(this).data("add-workspace-item-initialized", true);
             html = $(this).html();
             html = '<span class="ss_sprite ss_add sidebarbox-action-icon add-workspace-item" title="Voeg laag toe aan workspace">&nbsp;</span>' + html;
             $(this).html(html);
+            // Re-initialize tooltips, they are often in a
+            // workspace-acceptable.
+            setUpTooltips();
         }
     });
     // Do not use mouseout: Mouseout is also activated when moving to
@@ -252,26 +254,6 @@ function setUpWorkspaceAcceptable() {
             function (workspace_id) {
                 var url, center_x, center_y;
                 refreshMapActionsDivs();
-                // Load extent from workspace and zoom to it.
-	        // Disabled to avoid auto zoom
-	        /*
-                url = $(".workspace").attr(
-                    "data-url-lizard-map-session-workspace-extent-temp");
-                $.getJSON(url, {}, function (extent) {
-                    var ol_extent;
-                    // If we do not get extent, just forget it.
-                    if ((extent.north !== null) &&
-                        (extent.south !== null) &&
-                        (extent.east !== null) &&
-                        (extent.west !== null))
-                    {
-                        ol_extent = new OpenLayers.Bounds(
-                            extent.west, extent.south,
-                            extent.east, extent.north);
-                        map.zoomToExtent(ol_extent, true);
-                    }
-                });
-		*/
             });
         stretchOneSidebarBox();
         reenableWorkspaceItem($workspace_acceptable);
