@@ -13,6 +13,8 @@ import csv
 import logging
 import mapnik
 
+from lizard_ui.models import ApplicationScreen
+
 from lizard_map import coordinates
 from lizard_map.adapter import parse_identifier_json
 from lizard_map.animation import slider_layout_extra
@@ -49,14 +51,26 @@ def homepage(request,
     parameter 'screen' from url.
     """
 
-    if crumbs_prepend is not None:
-        crumbs = list(crumbs_prepend)
-    else:
-        crumbs = [CRUMBS_HOMEPAGE]
-
     if application_screen_slug is None:
         application_screen_slug = request.GET.get('screen', None)
 
+    if crumbs_prepend is None:
+        if application_screen_slug:
+            application_screen = get_object_or_404(
+                ApplicationScreen,
+                slug=application_screen_slug)
+            crumbs = [application_screen.crumb(), ]
+            if application_screen_slug != 'home':
+                # prepend with "home"
+                application_screen_home = get_object_or_404(
+                    ApplicationScreen,
+                    slug='home')
+                crumbs = [application_screen_home.crumb(), ] + crumbs
+        else:
+            crumbs = [CRUMBS_HOMEPAGE]
+    else:
+        crumbs = list(crumbs_prepend)
+
     # Determine if we want to show the video. Only show it once every day or
     # so.
     if popup_video_url is not None:
@@ -154,7 +168,7 @@ def workspace_item_add(request,
     workspace.workspace_items.create(adapter_class=adapter_class,
                                      index=max_index + 10,
                                      adapter_layer_json=adapter_layer_json,
-                                     name=name)
+                                     name=name[:80])
     return HttpResponse(json.dumps(workspace.id))
 
 
@@ -165,7 +179,10 @@ def workspace_item_empty(request,
                        template='lizard_map/tag_workspace.html'):
     """Clear workspace items for given workspace."""
     workspace = get_object_or_404(Workspace, pk=workspace_id)
-    workspace.workspace_items.all().delete()
+    # We loop through the workspace items, so the custom delete
+    # functions will be called. #3031
+    for workspace_item in workspace.workspace_items.all():
+        workspace_item.delete()
 
     return HttpResponse("")
 
@@ -857,9 +874,16 @@ def search_name(request):
         for workspace in workspace_collection:
             for workspace_item in workspace.workspace_items.filter(
                 visible=True):
-                search_results = workspace_item.adapter.search(
-                    google_x, google_y, radius=radius)
-                found += search_results
+
+                try:
+                    search_results = workspace_item.adapter.search(
+                        google_x, google_y, radius=radius)
+                    found += search_results
+                except:
+                    logger.exception(
+                        "Crashed while calling search_name on %s" %
+                        workspace_item)
+
     if found:
         # ``found`` is a list of dicts {'distance': ..., 'timeserie': ...}.
         found.sort(key=lambda item: item['distance'])
@@ -916,9 +940,15 @@ def search_coordinates(request):
         for workspace in workspace_collection:
             for workspace_item in workspace.workspace_items.filter(
                 visible=True):
-                search_results = workspace_item.adapter.search(
-                    google_x, google_y, radius=radius_search)
-                found += search_results
+
+                # #3033. Ignore crashing searches.
+                try:
+                    search_results = workspace_item.adapter.search(
+                        google_x, google_y, radius=radius_search)
+                    found += search_results
+                except:
+                    logger.exception("Crashed while calling search on %s" %
+                                     workspace_item)
     if found:
         # ``found`` is a list of dicts {'distance': ..., 'timeserie': ...}.
         found.sort(key=lambda item: item['distance'])
