@@ -129,7 +129,7 @@ class WorkspaceManager:
             changes = True
 
         #create collage if necessary, it is stored in the workspace
-        if len(self.workspaces[USER_WORKSPACES][0].collages.all()) == 0:
+        if self.workspaces[USER_WORKSPACES][0].collages.count() == 0:
             self.workspaces[USER_WORKSPACES][0].collages.create()
 
         if changes:
@@ -193,15 +193,18 @@ class WorkspaceItemAdapter(object):
         """
         raise NotImplementedError
 
-    def extent(self, identifiers=None):
-        """
-        Returns extent {'west':.., 'north':.., 'east':.., 'south':..}
-        in google projection. None for each key means unknown.
+    # def extent(self, identifiers=None):
+    #     """
+    #     Returns extent {'west':.., 'north':.., 'east':.., 'south':..}
+    #     in google projection. None for each key means unknown.
 
-        Optional: If identifiers is given, return extent for those
-        identifiers only.
-        """
-        return {'north': None, 'south': None, 'east': None, 'west': None}
+    #     Optional function. If available, there will be an magnifier
+    #     in your workspace -> workspace-item.
+
+    #     Optional: If identifiers is given, return extent for those
+    #     identifiers only.
+    #     """
+    #     return {'north': None, 'south': None, 'east': None, 'west': None}
 
     def search(self, x, y, radius=None):
         """Search by coordinates. Return list of dicts for matching
